.. py:currentmodule:: NonlinearTMM

Material
########

Main class
**********

.. autoclass:: NonlinearTMM.Material
   :members:
   :inherited-members:
   :show-inheritance:

Helper classes
**************

.. autoclass:: NonlinearTMM._Chi2Tensor
   :members:
   :inherited-members:
   :show-inheritance:
